import java.io.*;


class charCodeConverter {

	String globalInputFileName;
	String globalOutputFileName; 
	String globalInputEncoding;
	String globalOutputEncoding;

	//constructor
	charCodeConverter(
		String inputFileName, 
		String outputFileName, 
		String inputEncoding,
		String outputEncoding
	) {

		//store input values
		globalInputFileName=inputFileName;
		globalOutputFileName=outputFileName; 
		globalInputEncoding=inputEncoding;
		globalOutputEncoding=outputEncoding;

	//end of constructor	
	};	


	//do the conversion	- String is null string if no error
	public String convert() {
		InputStreamReader ins;
		OutputStreamWriter outs;
		FileInputStream infs;
		FileOutputStream outfs;

		try {
			infs=new FileInputStream(globalInputFileName);
		} catch (IOException ex) {
			String localerrnote="IOException opening Input File";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		try {
			outfs=new FileOutputStream(globalOutputFileName);
		} catch (IOException ex) {
			String localerrnote="IOException opening Output File";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		try{
			ins = new InputStreamReader ( infs, globalInputEncoding );
                } catch (UnsupportedEncodingException ex) {
			String localerrnote="UnsupportedEncodingException for Input";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		try{
			outs= new OutputStreamWriter( outfs, globalOutputEncoding );
                } catch (UnsupportedEncodingException ex) {
			String localerrnote="UnsupportedEncodingException for Output";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		int incharacter=0;
		try {
			incharacter=ins.read();
			while(incharacter!=-1) {
				if (incharacter!=0) outs.write(incharacter);
				incharacter=ins.read();
			};
		} catch (IOException ex) {
			String localerrnote="IOException when reading in & writing out";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};


		//CLOSE FILES
		try {
			ins.close();
		} catch (IOException ex) {
			String localerrnote="IOException when closing input file";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		try {
			outs.close();
		} catch (IOException ex) {
			String localerrnote="IOException when closing output file";
			String errnote=localerrnote+" "+ex.getMessage();
			return errnote;
		};

		//return Null String if no error
		return (""); 

	//end conversion function
	}; 
			
			
	public static void main(String args[]) {
		if (args.length!=4) {
			System.out.println("charCodeConverter takes 4 parameters");
			System.out.println("InputFileName");
			System.out.println("OutputFileName");
			System.out.println("Input Encoding");
			System.out.println("Output Encoding");

			
System.out.println(" ASCII                      American Standard Code for Information Interchange");
System.out.println(" Cp1252                     Windows Latin-1 ");
System.out.println(" ISO8859_1                  ISO 8859-1, Latin alphabet No. 1 ");
System.out.println(" UnicodeBig                 Sixteen-bit Unicode Transformation Format, big-endian byte order, with byte-order mark ");
System.out.println(" UnicodeBigUnmarked         Sixteen-bit Unicode Transformation Format, big-endian byte order ");
System.out.println(" UnicodeLittle              Sixteen-bit Unicode Transformation Format, little-endian byte order, with byte-order mark ");
System.out.println(" UnicodeLittleUnmarked      Sixteen-bit Unicode Transformation Format, little-endian byte order ");
System.out.println(" UTF8                       Eight-bit Unicode Transformation Format ");
System.out.println(" UTF-16                     Sixteen-bit Unicode Transformation Format, byte order specified by a mandatory initial byte-order mark ");
System.out.println("");
System.out.println(" Extended Encoding Set (contained in i18n.jar)");
System.out.println("");
System.out.println(" Big5                     Big5, Traditional Chinese ");
System.out.println(" Cp037                    USA, Canada (Bilingual, French), Netherlands, Portugal, Brazil, Australia ");
System.out.println(" Cp273                    IBM Austria, Germany ");
System.out.println(" Cp277                    IBM Denmark, Norway ");
System.out.println(" Cp278                    IBM Finland, Sweden ");
System.out.println(" Cp280                    IBM Italy ");
System.out.println(" Cp284                    IBM Catalan/Spain, Spanish Latin America ");
System.out.println(" Cp285                    IBM United Kingdom, Ireland ");
System.out.println(" Cp297                    IBM France ");
System.out.println(" Cp420                    IBM Arabic ");
System.out.println(" Cp424                    IBM Hebrew ");
System.out.println(" Cp437                    MS-DOS United States, Australia, New Zealand, South Africa ");
System.out.println(" Cp500                    EBCDIC 500V1 ");
System.out.println(" Cp737                    PC Greek ");
System.out.println(" Cp775                    PC Baltic ");
System.out.println(" Cp838                    IBM Thailand extended SBCS ");
System.out.println(" Cp850                    MS-DOS Latin-1 ");
System.out.println(" Cp852                    MS-DOS Latin-2 ");
System.out.println(" Cp855                    IBM Cyrillic ");
System.out.println(" Cp856                    IBM Hebrew ");
System.out.println(" Cp857                    IBM Turkish ");
System.out.println(" Cp858                    Variant of Cp850 with Euro character ");
System.out.println(" Cp860                    MS-DOS Portuguese ");
System.out.println(" Cp861                    MS-DOS Icelandic ");
System.out.println(" Cp862                    PC Hebrew ");
System.out.println(" Cp863                    MS-DOS Canadian French ");
System.out.println(" Cp864                    PC Arabic ");
System.out.println(" Cp865                    MS-DOS Nordic ");
System.out.println(" Cp866                    MS-DOS Russian ");
System.out.println(" Cp868                    MS-DOS Pakistan ");
System.out.println(" Cp869                    IBM Modern Greek ");
System.out.println(" Cp870                    IBM Multilingual Latin-2 ");
System.out.println(" Cp871                    IBM Iceland ");
System.out.println(" Cp874                    IBM Thai ");
System.out.println(" Cp875                    IBM Greek ");
System.out.println(" Cp918                    IBM Pakistan (Urdu) ");
System.out.println(" Cp921                    IBM Latvia, Lithuania (AIX, DOS) ");
System.out.println(" Cp922                    IBM Estonia (AIX, DOS) ");
System.out.println(" Cp930                    Japanese Katakana-Kanji mixed with 4370 UDC, superset of 5026 ");
System.out.println(" Cp933                    Korean Mixed with 1880 UDC, superset of 5029 ");
System.out.println(" Cp935                    Simplified Chinese Host mixed with 1880 UDC, superset of 5031 ");
System.out.println(" Cp937                    Traditional Chinese Host miexed with 6204 UDC, superset of 5033 ");
System.out.println(" Cp939                    Japanese Latin Kanji mixed with 4370 UDC, superset of 5035 ");
System.out.println(" Cp942                    IBM OS/2 Japanese, superset of Cp932 ");
System.out.println(" Cp942C                   Variant of Cp942 ");
System.out.println(" Cp943                    IBM OS/2 Japanese, superset of Cp932 and Shift-JIS ");
System.out.println(" Cp943C                   Variant of Cp943 ");
System.out.println(" Cp948                    OS/2 Chinese (Taiwan) superset of 938 ");
System.out.println(" Cp949                    PC Korean ");
System.out.println(" Cp949C                   Variant of Cp949 ");
System.out.println(" Cp950                    PC Chinese (Hong Kong, Taiwan) ");
System.out.println(" Cp964                    AIX Chinese (Taiwan) ");
System.out.println(" Cp970                    AIX Korean ");
System.out.println(" Cp1006                   IBM AIX Pakistan (Urdu) ");
System.out.println(" Cp1025                   IBM Multilingual Cyrillic: Bulgaria, Bosnia, Herzegovinia, Macedonia (FYR) ");
System.out.println(" Cp1026                   IBM Latin-5, Turkey ");
System.out.println(" Cp1046                   IBM Arabic - Windows ");
System.out.println(" Cp1097                   IBM Iran (Farsi)/Persian ");
System.out.println(" Cp1098                   IBM Iran (Farsi)/Persian (PC) ");
System.out.println(" Cp1112                   IBM Latvia, Lithuania ");
System.out.println(" Cp1122                   IBM Estonia ");
System.out.println(" Cp1123                   IBM Ukraine ");
System.out.println(" Cp1124                   IBM AIX Ukraine ");
System.out.println(" Cp1140                   Variant of Cp037 with Euro character ");
System.out.println(" Cp1141                   Variant of Cp273 with Euro character ");
System.out.println(" Cp1142                   Variant of Cp277 with Euro character ");
System.out.println(" Cp1143                   Variant of Cp278 with Euro character ");
System.out.println(" Cp1144                   Variant of Cp280 with Euro character ");
System.out.println(" Cp1145                   Variant of Cp284 with Euro character ");
System.out.println(" Cp1146                   Variant of Cp285 with Euro character ");
System.out.println(" Cp1147                   Variant of Cp297 with Euro character ");
System.out.println(" Cp1148                   Variant of Cp500 with Euro character ");
System.out.println(" Cp1149                   Variant of Cp871 with Euro character ");
System.out.println(" Cp1250                   Windows Eastern European ");
System.out.println(" Cp1251                   Windows Cyrillic ");
System.out.println(" Cp1253                   Windows Greek ");
System.out.println(" Cp1254                   Windows Turkish ");
System.out.println(" Cp1255                   Windows Hebrew ");
System.out.println(" Cp1256                   Windows Arabic ");
System.out.println(" Cp1257                   Windows Baltic ");
System.out.println(" Cp1258                   Windows Vietnamese ");
System.out.println(" Cp1381                   IBM OS/2, DOS People's Republic of China (PRC) ");
System.out.println(" Cp1383                   IBM AIX People's Republic of China (PRC) ");
System.out.println(" Cp33722                  IBM-eucJP - Japanese (superset of 5050) ");
System.out.println(" EUC_CN                   GB2312, EUC encoding, Simplified Chinese ");
System.out.println(" EUC_JP                   JIS X 0201, 0208, 0212, EUC encoding, Japanese ");
System.out.println(" EUC_KR                   KS C 5601, EUC encoding, Korean ");
System.out.println(" EUC_TW                   CNS11643 (Plane 1-3), EUC encoding, Traditional Chinese ");
System.out.println(" GBK                      GBK, Simplified Chinese ");
System.out.println(" ISO2022CN                ISO 2022 CN, Chinese (conversion to Unicode only) ");
System.out.println(" ISO2022CN_CNS            CNS 11643 in ISO 2022 CN form, Traditional Chinese (conversion from Unicode only) ");
System.out.println(" ISO2022CN_GB             GB 2312 in ISO 2022 CN form, Simplified Chinese (conversion from Unicode only) ");
System.out.println(" ISO2022JP                JIS X 0201, 0208 in ISO 2022 form, Japanese ");
System.out.println(" ISO2022KR                ISO 2022 KR, Korean ");
System.out.println(" ISO8859_2                ISO 8859-2, Latin alphabet No. 2 ");
System.out.println(" ISO8859_3                ISO 8859-3, Latin alphabet No. 3 ");
System.out.println(" ISO8859_4                ISO 8859-4, Latin alphabet No. 4 ");
System.out.println(" ISO8859_5                ISO 8859-5, Latin/Cyrillic alphabet ");
System.out.println(" ISO8859_6                ISO 8859-6, Latin/Arabic alphabet ");
System.out.println(" ISO8859_7                ISO 8859-7, Latin/Greek alphabet ");
System.out.println(" ISO8859_8 		  ISO 8859-8, Latin/Hebrew alphabet ");
System.out.println(" ISO8859_9                ISO 8859-9, Latin alphabet No. 5 ");
System.out.println(" ISO8859_13               ISO 8859-13, Latin alphabet No. 7 ");
System.out.println(" ISO8859_15_FDIS          ISO 8859-15, Latin alphabet No. 9 ");
System.out.println(" JIS0201                  JIS X 0201, Japanese ");
System.out.println(" JIS0208                  JIS X 0208, Japanese ");
System.out.println(" JIS0212                  JIS X 0212, Japanese ");
System.out.println(" JISAutoDetect            Detects and converts from Shift-JIS, EUC-JP, ISO 2022 JP (conversion to Unicode only) ");
System.out.println(" Johab                    Johab, Korean ");
System.out.println(" KOI8_R                   KOI8-R, Russian ");
System.out.println(" MS874                    Windows Thai ");
System.out.println(" MS932                    Windows Japanese ");
System.out.println(" MS936                    Windows Simplified Chinese ");
System.out.println(" MS949                    Windows Korean ");
System.out.println(" MS950                    Windows Traditional Chinese ");
System.out.println(" MacArabic                Macintosh Arabic ");
System.out.println(" MacCentralEurope         Macintosh Latin-2 ");
System.out.println(" MacCroatian              Macintosh Croatian ");
System.out.println(" MacCyrillic              Macintosh Cyrillic ");
System.out.println(" MacDingbat               Macintosh Dingbat ");
System.out.println(" MacGreek                 Macintosh Greek ");
System.out.println(" MacHebrew                Macintosh Hebrew ");
System.out.println(" MacIceland               Macintosh Iceland ");
System.out.println(" MacRoman                 Macintosh Roman ");
System.out.println(" MacRomania               Macintosh Romania ");
System.out.println(" MacSymbol                Macintosh Symbol ");
System.out.println(" MacThai                  Macintosh Thai ");
System.out.println(" MacTurkish               Macintosh Turkish ");
System.out.println(" MacUkraine               Macintosh Ukraine ");
System.out.println(" SJIS                     Shift-JIS, Japanese ");
System.out.println(" TIS620                   TIS620, Thai ");


			return;

		};



	charCodeConverter ccc;
	ccc=new charCodeConverter(args[0],args[1],args[2],args[3]);
	System.out.println(ccc.convert());

	//end of static member function "main"
	};


}